/*
** Module   : PortableMouseEvent.java
** Abstract : Container for an event generated by client-side, having as source a mouse.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20141020 Created initial version.
** 002 CA  20141029 Added c'tors to allow specification of event labels instead of event codes
**                  (as the event codes are dependent on the client's compatibility mode (ChUI/GUI,
**                  Windows/Linux).
*/

package com.goldencode.p2j.ui.client.event;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * Container for an event generated by client-side, having as source a mouse.
 */
public class PortableMouseEvent
extends Event
{
   /** The 4GL action associated with this event. */
   private int action;

   /**
    * Create a new event for the specified widget, with the specified event label.
    * 
    * @param    widget
    *           The source widget.
    * @param    label
    *           The event label.
    */
   public PortableMouseEvent(Widget<?> widget, String label)
   {
      this(widget, label, label);
   }

   /**
    * Create a new event for the specified widget, with the specified ID.
    * 
    * @param    widget
    *           The source widget.
    * @param    id
    *           The event ID.
    */
   public PortableMouseEvent(Widget<?> widget, int id)
   {
      this(widget, id, id);
   }

   /**
    * Create a new event for the specified widget, with the specified ID.
    * 
    * @param    widget
    *           The source widget.
    * @param    label
    *           The event's label.
    * @param    action
    *           The associated action.
    */
   public PortableMouseEvent(Widget<?> widget, String label, int action)
   {
      super(widget, Keyboard.keyCode(label));
      
      this.action = action;
   }

   /**
    * Create a new event for the specified widget, with the specified ID.
    * 
    * @param    widget
    *           The source widget.
    * @param    label
    *           The event's label.
    * @param    action
    *           The associated action.
    */
   public PortableMouseEvent(Widget<?> widget, String label, String action)
   {
      super(widget, Keyboard.keyCode(label));
      
      this.action = Keyboard.keyCode(action);
   }

   /**
    * Create a new event for the specified widget, with the specified ID.
    * 
    * @param    widget
    *           The source widget.
    * @param    id
    *           The event ID.
    * @param    action
    *           The associated action.
    */
   public PortableMouseEvent(Widget<?> widget, int id, int action)
   {
      super(widget, id);
      
      this.action = action;
   }
   
   /**
    * Get the {@link #action}.
    * 
    * @return    See above.
    */
   public int getAction()
   {
      return action;
   }
}
