/*
** Module   : GuiKeyboard.java
** Abstract : Keyboard configuration for Windows GUI clients. 
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20141029 Created initial version.
*/

package com.goldencode.p2j.ui.client.gui;

import java.util.*;

import com.goldencode.p2j.ui.client.chui.*;

/**
 * This class contains the configurations for a Keyboard compatible with the Windows GUI clients.
 */
public class GuiKeyboard
extends ChuiWindowsKeyboard
{
   /**
    * Get the mappings of standard functions to their associated keys.
    * 
    * @return   See above.
    */
   @Override
   protected Map<String, String[]> standardKeyFunctions()
   {
      Map<String, String[]> res = new HashMap<>();
      
      res.put(BACK_TAB,  new String[] {"SHIFT-TAB"});
      res.put(BACKSPACE, new String[] {"BACKSPACE"});
      res.put(BELL,      new String[] {"CTRL-G", "BELL"});

      res.put(CLOSE,        new String[] {"F8"});
      res.put(COMPILE,      new String[] {"SHIFT-F2"});
      res.put(CURSOR_DOWN,  new String[] {"CURSOR-DOWN"});
      res.put(CURSOR_LEFT,  new String[] {"CURSOR-LEFT"});
      res.put(CURSOR_RIGHT, new String[] {"CURSOR-RIGHT"});
      res.put(CURSOR_UP,    new String[] {"CURSOR-UP"});  
      res.put(CUT,          new String[] {"CTRL-X"});
      
      res.put(DELETE_CHARACTER, new String[] {"DEL"});
      
      res.put(END,           new String[] {"END"});
      res.put(END_ERROR,     new String[] {"ESC"});
      res.put(ENTER_MENUBAR, new String[] {"ALT"});
      
      res.put(FIND,          new String[] {"CTRL-F"});
      res.put(FIND_NEXT,     new String[] {"F9"});
      res.put(FIND_PREVIOUS, new String[] {"SHIFT-F9"});
      
      res.put(GET,  new String[] {"F3"});
      res.put(GO,   new String[] {"F2"});
      res.put(GOTO, new String[] {"CTRL-G"});
      
      res.put(HELP, new String[] {"F1"});
      res.put(HOME, new String[] {"HOME"});
      
      res.put(INSERT_MODE, new String[] {"INSERT", "INS"});
      
      res.put(LEFT_END, new String[] {"HOME"});
      
      res.put(NEW,        new String[] {"SHIFT-F3"});
      res.put(NEXT_FRAME, new String[] {"F6"});
      
      res.put(PAGE_DOWN,  new String[] {"PAGE-DOWN", "PGDN", "NEXT-PAGE", "NEXT-SCRN"});
      res.put(PAGE_UP,    new String[] {"PAGE-UP", "PGUP", "PREV-PAGE", "PREV-SCRN"});
      res.put(PASTE,      new String[] {"CTRL-V"});
      res.put(PREV_FRAME, new String[] {"SHIFT-F6"});
      res.put(PUT,        new String[] {"F6"});
      
      res.put(RETURN, new String[] {"ENTER", "RETURN", "CTRL-M"});
      
      res.put(SAVE_AS, new String[] {"SHIFT-F6"});
      res.put(STOP,    new String[] {"CTRL-BREAK"});
      
      res.put(TAB,     new String[] {"TAB"});
      
      // special entries for key actions
      res.put(ENDKEY, new String[] {});
      res.put(ERROR,  new String[] {});

      return res;
   }
}
