/*
** Module   : GuiClient.java
** Abstract : GUI main screen.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 MAG 20140508 First version.
** 002 MAG 20140925 Hide constructor.
** 003 CA  20141021 Do not allow GUI windows to be closed via OS (i.e. ALT-F4).
** 004 CA  20141029 Each client needs to receive the swing keyboard reader implementation in 
**                  use.  It's the callers responsibility to ensure that the same instance is used
**                  for all simulators, if the client is ran in a multi-window mode (i.e. GUI).
*/

package com.goldencode.p2j.ui.client.gui.driver.swing;

import java.lang.reflect.*;

import javax.swing.*;

import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.gui.driver.*;
import com.goldencode.p2j.ui.client.swing.*;

/** 
 * Main GUI client class which instantiates the primary frame window.
 */
@SuppressWarnings("serial")
public class GuiClient 
extends AbstractClient
{
   /** Frame title. */
   private static String title = "P2J GUI Client";

   /** Simulator instance. */
   private GuiSimulator sim = null;

   /**
    * Construct the new frame by instantiating the {@link GuiSimulator} as the
    * content pane and initializing it using the given <code>options</code>.
    * 
    * @param   options
    *          The configuration parameters for the content pane.
    * @param   keyReader
    *          The {@link SwingKeyboardReader key reader} which listens for incoming keys.
    */
   private GuiClient(GuiOptions options, SwingKeyboardReader keyReader)
   {
      super(title);
      // common initialization
      sim = new GuiSimulator(this, options, keyReader);
      init(sim, true);
   }

   /**
    * Initialize the application frame by creating a new instance of this class
    * and of the content pane which is an instance of {@link GuiSimulator}.
    * 
    * @param    options
    *           The configuration parameters for the content pane.
    * @param    keyReader
    *           The {@link SwingKeyboardReader key reader} which listens for incoming keys.
    *           
    * @return   The simulator instance.
    */
   public static GuiSimulator load(final GuiOptions options, final SwingKeyboardReader keyReader) 
   throws InterruptedException,
          InvocationTargetException
   {
      // lame hack because of Java flaw
      final GuiClient[] client = new GuiClient[1];

      // instantiate the application's main frame
      SwingUtilities.invokeAndWait(new Runnable()
      {
         public void run()
         {
            client[0] = new GuiClient(options, keyReader);
         }
      });

      return client[0].sim;
   }
   
   /**
    * Initialize.  GUI windows are not allowed to be closed via OS (i.e. ALT-F4).
    * 
    * @param   pane
    *          Content pane.
    * @param   resizable
    *          Resizable attribute.
    */
   @Override
   protected void init(JComponent pane, boolean resizable)
   {
      super.init(pane, resizable);

      setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
   }
}
